package com.contentinsights.contentinsightssdk;

import android.content.Intent;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.View;
import android.webkit.WebView;

import com.contentinsights.contentinsightssdk.helpers.NjuzOperations;
import com.contentinsights.sdk.ContentInsights;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

public class ArticleActivity extends AppCompatActivity {

    private static String KEY_IS_ALREADY_SENT_READ_REQUEST = "keyAlreadySentReadReq";

    WebView webView;
    String articleUrl;
    boolean isAlreadySentReadRequest = false;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_article);

        if (savedInstanceState != null) {
            isAlreadySentReadRequest = savedInstanceState.getBoolean(KEY_IS_ALREADY_SENT_READ_REQUEST);
        }

        Intent intent = getIntent();
        articleUrl = intent.getStringExtra("articleUrl");


        String articleId = intent.getStringExtra("articlePublisherId");
        ContentInsights.tracking().startArticleReadTracker(articleUrl, articleId);
        ContentInsights.tracking().startAttentionTracker(articleUrl, articleId);

        webView = findViewById(R.id.wvArticle);
        webView.getSettings().setJavaScriptEnabled(false);
        webView.loadUrl(articleUrl);

        webView.setOnScrollChangeListener(new View.OnScrollChangeListener() {
            @Override
            public void onScrollChange(View view, int i, int i1, int i2, int i3) {
                ContentInsights.tracking().setNewScrollPosition(i3);
            }
        });
    }

    @Override
    protected void onSaveInstanceState(Bundle outState) {
        outState.putBoolean(KEY_IS_ALREADY_SENT_READ_REQUEST, isAlreadySentReadRequest);
        super.onSaveInstanceState(outState);
    }

    @Override
    public void onStart() {
        super.onStart();
        ContentInsights.tracking().startAttention();
    }

    @Override
    public void onResume() {
        super.onResume();
        ContentInsights.tracking().startAttention();
    }

    @Override
    public void onPause() {
        super.onPause();
        ContentInsights.tracking().pauseAttention();
    }

    @Override
    public void onStop() {
        super.onStop();
        ContentInsights.tracking().pauseAttention();
    }

    @Override
    public void onDestroy() {
        ContentInsights.tracking().pauseAttention();
        if(isFinishing()) {
            ContentInsights.tracking().flushArticle();
        }
        super.onDestroy();
    }

    private Date tryToParseDate(String articlePublishDate) {
        try {
            return new SimpleDateFormat(NjuzOperations.DATE_FORMAT).parse(articlePublishDate);
        } catch (ParseException e) {
            return new Date();
        }
    }
}
