package com.contentinsights.contentinsightssdk

import android.os.Bundle
import android.support.v7.app.AppCompatActivity
import android.util.Log
import android.view.View
import android.webkit.WebView
import com.contentinsights.contentinsightssdk.helpers.NjuzOperations
import com.contentinsights.sdk.ContentInsights
import java.text.ParseException
import java.text.SimpleDateFormat
import java.util.*

class KotlinArticleActivity : AppCompatActivity() {
    var webView: WebView? = null
    var articleUrl: String? = null
    var isAlreadySentReadRequest = false

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_article)
        if (savedInstanceState != null) {
            isAlreadySentReadRequest = savedInstanceState.getBoolean(KEY_IS_ALREADY_SENT_READ_REQUEST)
        }
        val intent = intent
        articleUrl = intent.getStringExtra("articleUrl")
        val articleId = intent.getStringExtra("articlePublisherId")
        ContentInsights.tracking().startArticleReadTracker(articleUrl, articleId)
        ContentInsights.tracking().startAttentionTracker(articleUrl, articleId)
        webView = findViewById(R.id.wvArticle)
        webView!!.getSettings().javaScriptEnabled = false
        webView!!.loadUrl(articleUrl)
        webView!!.setOnScrollChangeListener(View.OnScrollChangeListener { view, i, i1, i2, i3 -> ContentInsights.tracking().setNewScrollPosition(i3) })
    }

    override fun onSaveInstanceState(outState: Bundle) {
        outState.putBoolean(KEY_IS_ALREADY_SENT_READ_REQUEST, isAlreadySentReadRequest)
        super.onSaveInstanceState(outState)
    }

    public override fun onStart() {
        super.onStart()
        ContentInsights.tracking().startAttention()
    }

    public override fun onResume() {
        super.onResume()
        ContentInsights.tracking().startAttention()
    }

    public override fun onPause() {
        super.onPause()
        ContentInsights.tracking().pauseAttention()
    }

    public override fun onStop() {
        super.onStop()
        ContentInsights.tracking().pauseAttention()
    }

    public override fun onDestroy() {
        ContentInsights.tracking().pauseAttention()
        if (isFinishing) {
            ContentInsights.tracking().flushArticle()
        }
        super.onDestroy()
    }

    private fun tryToParseDate(articlePublishDate: String): Date {
        return try {
            SimpleDateFormat(NjuzOperations.DATE_FORMAT).parse(articlePublishDate)
        } catch (e: ParseException) {
            Date()
        }
    }

    companion object {
        private const val KEY_IS_ALREADY_SENT_READ_REQUEST = "keyAlreadySentReadReq"
    }
}