package com.contentinsights.contentinsightssdk;

import android.app.AlertDialog;
import android.app.ProgressDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ListView;

import com.contentinsights.contentinsightssdk.helpers.AppHelper;
import com.contentinsights.contentinsightssdk.helpers.NjuzOperations;
import com.contentinsights.contentinsightssdk.models.Article;
import com.contentinsights.contentinsightssdk.models.ArticleList;
import com.contentinsights.contentinsightssdk.adapters.ArticlesListAdapter;

public class MainActivity extends AppCompatActivity {

    private ListView listView;
    private ProgressDialog dlg;
    private AppHelper appHelper;
    private ArticleList articleList;
    private ArticlesListAdapter articlesListAdapter;

    @Override
    protected void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        this.appHelper = new AppHelper();

        // Get the listview
        this.listView = findViewById(R.id.lvArticles);

        // Preparing list data
        this.loadArticles();
    }

    /**
     * Load articles
     */
    private void loadArticles()
    {
        Thread mThread = new Thread() {
            @Override
            public void run() {
                try {
                    runOnUiThread(new Runnable() {
                        @Override
                        public void run() {
                            MainActivity.this.dlg = appHelper.ShowProgressMessage(
                                    MainActivity.this,
                                    "Loading articles...",
                                    false);
                        }
                    });

                    NjuzOperations njuzOperations = new NjuzOperations();
                    articleList = njuzOperations.getArticleList();

                    appHelper.dismissDialog(MainActivity.this.dlg);

                    // Display error message
                    if (!articleList.isSuccess()) {
                        runOnUiThread(new Runnable() {
                            @Override
                            public void run() {
                                appHelper.showActivityErrorMessage(
                                        MainActivity.this,
                                        "Error", articleList.getMessage()
                                );
                            }
                        });
                    } else {
                        articlesListAdapter = new ArticlesListAdapter(
                                MainActivity.this,
                                articleList.getArticles(),
                                R.layout.article_list_item
                        );

                        // setting list adapter
                        runOnUiThread(new Runnable() {
                            @Override
                            public void run() {
                                listView.setAdapter(articlesListAdapter);
                                listView.setOnItemClickListener(new AdapterView.OnItemClickListener() {
                                    @Override
                                    public void onItemClick(AdapterView<?> arg0, View arg1, int position, long arg3) {
                                        Object obj = listView.getItemAtPosition(position);
                                        Article article = (Article) obj;

                                        if (position == 0) {
                                            Intent i = new Intent(
                                                    MainActivity.this,
                                                    LoremIpsumHtmlActivity.class
                                            );
                                            i.putExtra("articleId", article.getGuid());
                                            i.putExtra("articleUrl", article.getLink());
                                            startActivity(i);
                                            return;
                                        }

                                        Intent i;
                                        if (position % 2 == 0) {
                                            i = new Intent(
                                                    MainActivity.this,
                                                    ArticleActivity.class
                                            );
                                        } else {
                                            i = new Intent(
                                                    MainActivity.this,
                                                    KotlinArticleActivity.class
                                            );
                                        }

                                        // In our example we fetch articles meta-data at this point and pass them to our next activity.
                                        i.putExtra("articleTitle", article.getTitle());
                                        i.putExtra("articleUrl", article.getLink());
                                        i.putExtra("articlePublisherId", article.getGuid());
                                        i.putStringArrayListExtra("articleSections", article.getCategories());
                                        i.putExtra("articlePublishDate", article.getPublishDate());
                                        i.putStringArrayListExtra("articleAuthors", article.getAuthors());
                                        i.putStringArrayListExtra("articleTags", article.getTags());
                                        i.putExtra("commentsCount", article.getCommentsCount());
                                        i.putExtra("articleAccessLevel", article.getAccessLevel());
                                        i.putExtra("articleType", article.getType());
                                        i.putExtra("wc", article.getWordCount());
                                        i.putExtra("fb_count", article.getFbCount());
                                        i.putExtra("gp_count", article.getGpCount());
                                        i.putExtra("ln_count", article.getLnCount());
                                        i.putExtra("ok_count", article.getOkCount());
                                        i.putExtra("pn_count", article.getPnCount());
                                        i.putExtra("vk_count", article.getVkCount());
                                        // i.putExtra("custom_network", 13);

                                        startActivity(i);
                                    }
                                });
                            }
                        });

                    }
                } catch (Exception ex) {
                    runOnUiThread(new Runnable() {
                        @Override
                        public void run() {
                            appHelper.dismissDialog(MainActivity.this.dlg);
                        }
                    });
                }
            }};
        mThread.start();
    }

    @Override
    public void onBackPressed() {
        new AlertDialog.Builder(this)
                .setMessage("Are you sure you want to exit?")
                .setCancelable(false)
                .setPositiveButton("Yes", new DialogInterface.OnClickListener() {
                    public void onClick(DialogInterface dialog, int id) {
                        MainActivity.this.finish();
                    }
                })
                .setNegativeButton("No", null)
                .show();
    }
}
