package com.contentinsights.contentinsightssdk.helpers;

import com.contentinsights.contentinsightssdk.models.Article;
import com.contentinsights.contentinsightssdk.models.ArticleList;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlPullParserFactory;

import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.util.List;

public abstract class AbstractOperations
{
    XmlPullParserFactory xmlFactoryObject;
    XmlPullParser pullParser;

    /**
     * Get list of articles from server
     *
     * @return ArticleList
     */
    public ArticleList getArticleList() {
        ArticleList result = new ArticleList();
        List<Article> articles;
        try {
            articles = this.getArticles();
            result.setArticles(articles);
            result.setSuccess(true);
        } catch (IOException e) {
            result.setSuccess(false);
            result.setMessage(e.getMessage());
        } catch (XmlPullParserException e) {
            result.setSuccess(false);
            result.setMessage(e.getMessage());
        }

        return result;
    }

    /**
     * Get input stream
     *
     * @return InputStream
     */
    InputStream getInputStream(URL url) {
        try {
            return url.openConnection().getInputStream();
        } catch (IOException e) {
            return null;
        }
    }

    /**
     * Get articles
     *
     * @return List<Article> Articles
     */
    protected abstract List<Article> getArticles() throws IOException, XmlPullParserException;
}
