package com.contentinsights.contentinsightssdk.helpers;

import com.contentinsights.contentinsightssdk.models.Article;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlPullParserFactory;

import java.io.IOException;
import java.net.URL;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Random;

public class NjuzOperations extends AbstractOperations
{

    public static String DATE_FORMAT = "yyyy-MM-dd HH:mm";
    /**
     * Get articles
     *
     * @return List<Article> Articles
     */
    protected List<Article> getArticles() throws IOException, XmlPullParserException {
        List<Article> result = new ArrayList<>();
        URL url = new URL("https://www.njuz.net/feed/");
        this.xmlFactoryObject = XmlPullParserFactory.newInstance();
        this.xmlFactoryObject.setNamespaceAware(false);
        this.pullParser = xmlFactoryObject.newPullParser();

        this.pullParser.setInput(this.getInputStream(url), "UTF_8");

        boolean insideItem = false;
        int eventType = this.pullParser.getEventType();
        Article item = new Article();
        while (eventType != XmlPullParser.END_DOCUMENT) {
            if (eventType == XmlPullParser.START_TAG) {

                if (this.pullParser.getName().equalsIgnoreCase("item")) {
                    insideItem = true;
                } else if (this.pullParser.getName().equalsIgnoreCase("title")) {
                    if (insideItem) {
                        item.setTitle(this.pullParser.nextText());
                    }
                } else if (this.pullParser.getName().equalsIgnoreCase("link")) {
                    if (insideItem) {
                        item.setLink(this.pullParser.nextText());
                    }
                } else if (this.pullParser.getName().equalsIgnoreCase("description")) {
                    if (insideItem) {
                        item.setDescription(this.pullParser.nextText());
                    }
                } else if (this.pullParser.getName().equalsIgnoreCase("guid")) {
                    if (insideItem) {
                        String guid = this.pullParser.nextText().split("=")[1];
                        item.setGuid(guid);
                    }
                } else if (this.pullParser.getName().equalsIgnoreCase("category")) {
                    if (insideItem) {
                        if (item.getCategories().isEmpty()) {
                            String category = this.pullParser.nextText();
                            item.addCategory(category);
                        } else {
                            String tag = this.pullParser.nextText();
                            item.addTag(tag);
                        }
                    }
                } else if (this.pullParser.getName().equalsIgnoreCase("dc:creator")) {
                    if (insideItem) {
                        String creator = this.pullParser.nextText();
                        item.addAuthor(creator);
                    }
                } else if (this.pullParser.getName().equalsIgnoreCase("pubDate")) {
                    if (insideItem) {
                        String publishDate;
                        /*
                        Please use one of the following date formats
                        YYYY-MM-DD (e.g. 2013-09-06)
                        YYYY-MM-DD HH:MM (e.g. 2013-09-06 13:35)
                        YYYY-MM-DD HH:MM:SS (e.g. 2013-09-06 13:35:08)
                        */
                        try {
                            publishDate = new SimpleDateFormat(DATE_FORMAT).format(new SimpleDateFormat("EE, d MMM yyyy HH:mm:ss Z").parse(this.pullParser.nextText()));
                        } catch (ParseException e) {
                            publishDate = new SimpleDateFormat(DATE_FORMAT).format(new Date());
                        }
                        item.setPublishDate(publishDate);
                    }
                }
                else if (this.pullParser.getName().equalsIgnoreCase("slash:comments")) {
                    if (insideItem) {
                        String commentsCount = this.pullParser.nextText();
                        item.setCommentsCount(Integer.valueOf(commentsCount));
                    }
                }

            }else if (eventType==XmlPullParser.END_TAG
                    && this.pullParser.getName().equalsIgnoreCase("item")){
                insideItem=false;
            }

            if ((item.getTitle() != null || item.getDescription() != null) && !insideItem) {
                item.setAccessLevel("free");
                item.setType("news");

//                Random rand = new Random();
//                item.setWordCount(rand.nextInt(50));
//                item.setFbCount(rand.nextInt(50));
//                item.setGpCount(rand.nextInt(50));
//                item.setLnCount(rand.nextInt(50));
//                item.setOkCount(rand.nextInt(50));
//                item.setPnCount(rand.nextInt(50));
//                item.setVkCount(rand.nextInt(50));

                result.add(item);
                item = new Article();
            }

            eventType = this.pullParser.next();
        }

        return result;
    }
}
