package com.contentinsights.sdk.api;

/**
 * Predefined markers for different SDK features activation statuses.
 */
public class SdkFeatures {

    /**
     * None of the SDK features activated. With this setting SDK is almost as good as non-existing.
     */
    public static int NOTHING = 0;

    /**
     * Logging feature activated. With this feature, all trackings are only logged using standard
     * output, no real backend calls are made. It can be useful in debug, test or other
     * development phases.
     */
    public static int LOGGING = 1;

    /**
     * Activated feature for communicating with backend api in order to track and record data.
     * This is recommended feature setting in production.
     */
    public static int API_CALLING = 2;

    /**
     * With this feature, both logging to standard output and calling backend api
     * are activated.
     */
    public static int API_AND_LOGGING = 3;
}
