package com.contentinsights.sdk.helpers;

import java.sql.Timestamp;

public class TokenProvider {

    private Preferences preferences;
    private RandomGenerator randomGenerator;

    private String sessionToken = "";
    private int sessionTimeout = 0;

    private String visitToken = "";

    public TokenProvider(Preferences preferences, RandomGenerator randomGenerator, int sessionTimeout) {
        this.preferences = preferences;
        this.randomGenerator = randomGenerator;
        this.sessionTimeout = sessionTimeout;
    }

    public String getLifetimeToken() {
        String paramName = "lifetimeToken";
        String lifetimeToken = preferences.get(paramName);

        if (lifetimeToken.isEmpty()) {
            Timestamp timeStamp = getTimestamp();
            lifetimeToken = String.valueOf(timeStamp.getTime()) + "." + randomGenerator.generateToken();
            preferences.save(paramName, lifetimeToken);
        }

        return lifetimeToken;
    }

    public String getSessionToken() {
        if (sessionToken.isEmpty()) {
            sessionToken = makeNewSessionToken(getTimestamp());
        } else {
            String oldTimeStamp = sessionToken.substring(0, 10);
            Timestamp timestamp = getTimestamp();
            if (timestamp.getTime() - Integer.valueOf(oldTimeStamp) > sessionTimeout) {
                sessionToken = makeNewSessionToken(timestamp);
            }
        }

        return sessionToken;
    }

    public String getVisitToken() {
        return visitToken;
    }

    private Timestamp getTimestamp() {
        return new Timestamp(System.currentTimeMillis() / 1000);
    }

    private String makeNewSessionToken(Timestamp timestamp) {
        String time = "" + timestamp.getTime();
        String randomToken = randomGenerator.generateToken();
        return time + "." + randomToken;
    }

    public String makeNewVisitToken() {
        Timestamp timeStamp = new Timestamp(System.currentTimeMillis() / 1000);
        visitToken = String.valueOf(timeStamp.getTime()) + "." + randomGenerator.generateToken();

        return visitToken;
    }
}
