package com.contentinsights.sdk.requests;

import com.contentinsights.sdk.helpers.StringJoiner;

import java.net.URLEncoder;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

public class ApiTrackingRequest implements TrackingRequest {

    private String url;
    private String apiUrl;

    public ApiTrackingRequest(String apiUrl) {
        this.apiUrl = apiUrl;
    }

    public void send(Map<String, String> params) {
        params.put("os_ver", String.valueOf(android.os.Build.VERSION.SDK_INT));
        params.put("manuf", String.valueOf(android.os.Build.MANUFACTURER));

        String paramsUrlPart = createParamsUrlPart(params);
        url = String.format("%s%s%s", apiUrl, "?", paramsUrlPart);
        HttpGetRequest getRequest = new HttpGetRequest();
        getRequest.execute(url);
    }

    private String createParamsUrlPart(Map<String, String> params) {
        List<String> pairs = new LinkedList<>();

        for(Map.Entry<String, String> param : params.entrySet()) {
            if (paramExists(param.getValue())) {
                String key = param.getKey();
                String val = URLEncoder.encode(param.getValue());
                pairs.add(key + "=" + val);
            }
        }

        return new StringJoiner("&", pairs).joined();
    }

    private boolean paramExists(String param) {
        if (param == null) {
            return false;
        }
        param = param.trim();
        if (param.equals("null")) {
            return false;
        }

        if (param.isEmpty()) {
            return false;
        }

        return true;
    }
}
